# Summary

[Preamble](README.md)

- [Whence Parachains](whence-parachains.md)
- [Protocol Overview](protocol-overview.md)
  - [Approval Process](protocol-approval.md)
  - [Disputes Process](protocol-disputes.md)
    - [Dispute Flow](disputes-flow.md)
  - [Chain Selection and Finalization](protocol-chain-selection.md)
- [Architecture Overview](architecture.md)
  - [Messaging Overview](messaging.md)
  - [PVF Pre-checking](pvf-prechecking.md)
- [Runtime Architecture](runtime/README.md)
  - [`Initializer` Pallet](runtime/initializer.md)
  - [`Configuration` Pallet](runtime/configuration.md)
  - [`Shared` Pallet](runtime/shared.md)
  - [`Disputes` Pallet](runtime/disputes.md)
  - [`Paras` Pallet](runtime/paras.md)
  - [`Scheduler` Pallet](runtime/scheduler.md)
  - [`Inclusion` Pallet](runtime/inclusion.md)
  - [`ParaInherent` Pallet](runtime/parainherent.md)
  - [`DMP` Pallet](runtime/dmp.md)
  - [`HRMP` Pallet](runtime/hrmp.md)
  - [`Session Info` Pallet](runtime/session_info.md)
- [Runtime APIs](runtime-api/README.md)
  - [Validators](runtime-api/validators.md)
  - [Validator Groups](runtime-api/validator-groups.md)
  - [Availability Cores](runtime-api/availability-cores.md)
  - [Persisted Validation Data](runtime-api/persisted-validation-data.md)
  - [Session Index](runtime-api/session-index.md)
  - [Validation Code](runtime-api/validation-code.md)
  - [Candidate Pending Availability](runtime-api/candidate-pending-availability.md)
  - [Candidate Events](runtime-api/candidate-events.md)
  - [Disputes Info](runtime-api/disputes-info.md)
  - [Candidates Included](runtime-api/candidates-included.md)
  - [PVF Pre-checking](runtime-api/pvf-prechecking.md)
- [Node Architecture](node/README.md)
  - [Subsystems and Jobs](node/subsystems-and-jobs.md)
  - [Overseer](node/overseer.md)
  - [GRANDPA Voting Rule](node/grandpa-voting-rule.md)
  - [Collator Subsystems](node/collators/README.md)
    - [Collation Generation](node/collators/collation-generation.md)
    - [Collator Protocol](node/collators/collator-protocol.md)
  - [Backing Subsystems](node/backing/README.md)
    - [Candidate Backing](node/backing/candidate-backing.md)
    - [Prospective Parachains](node/backing/prospective-parachains.md)
    - [Statement Distribution](node/backing/statement-distribution.md)
    - [Statement Distribution (Legacy)](node/backing/statement-distribution-legacy.md)
  - [Availability Subsystems](node/availability/README.md)
    - [Availability Distribution](node/availability/availability-distribution.md)
    - [Availability Recovery](node/availability/availability-recovery.md)
    - [Bitfield Distribution](node/availability/bitfield-distribution.md)
    - [Bitfield Signing](node/availability/bitfield-signing.md)
  - [Approval Subsystems](node/approval/README.md)
    - [Approval Voting](node/approval/approval-voting.md)
    - [Approval Distribution](node/approval/approval-distribution.md)
  - [Disputes Subsystems](node/disputes/README.md)
    - [Dispute Coordinator](node/disputes/dispute-coordinator.md)
    - [Dispute Distribution](node/disputes/dispute-distribution.md)
  - [Utility Subsystems](node/utility/README.md)
    - [Availability Store](node/utility/availability-store.md)
    - [Candidate Validation](node/utility/candidate-validation.md)
      - [PVF Host and Workers](node/utility/pvf-host-and-workers.md)
    - [Provisioner](node/utility/provisioner.md)
    - [Network Bridge](node/utility/network-bridge.md)
    - [Gossip Support](node/utility/gossip-support.md)
    - [Peer Set Manager](node/utility/peer-set-manager.md)
    - [Runtime API Requests](node/utility/runtime-api.md)
    - [Chain API Requests](node/utility/chain-api.md)
    - [Chain Selection Request](node/utility/chain-selection.md)
    - [PVF Pre-Checking](node/utility/pvf-prechecker.md)
- [Data Structures and Types](types/README.md)
    - [Candidate](types/candidate.md)
    - [Backing](types/backing.md)
    - [Availability](types/availability.md)
    - [Overseer and Subsystem Protocol](types/overseer-protocol.md)
    - [Runtime](types/runtime.md)
    - [Messages](types/messages.md)
    - [Network](types/network.md)
    - [Approvals](types/approval.md)
    - [Disputes](types/disputes.md)
    - [PVF Pre-checking](types/pvf-prechecking.md)

[Glossary](glossary.md)
[Further Reading](further-reading.md)
